@@ -30,8 +30,12 @@ class Runtime:
         return Runtime._get_job_data()['job_auth_token']
 
     @staticmethod
-    def get_job_requested_machine() -> str:
-        return Runtime._get_job_data()['job_requested_machine']
+    def get_job_requested_machine() -> Optional[str]:
+        job_data = Runtime._get_job_data()
+        job_requested_machine = job_data.get('job_requested_machine')
+        if not job_requested_machine:
+            return None
+        return job_requested_machine
 
     @staticmethod
     def get_app_uri() -> str:
