@@ -250,6 +250,15 @@ class JobWorker:
         job = job_wrapper['job']
         self._jobs[job['public_id']] = job
 
+        app_version = job['app_version']
+        modules = app_version.get('modules', [])
+        for module in modules:
+            module_port_mappings = module.get('port_mappings', [])
+            if module_port_mappings:
+                logger_no_user_data.debug(
+                    f"Job '{job['public_id']}' module '{module['name']}' has port_mappings: {module_port_mappings}"
+                )
+
         if job['app_version'].get('modules') is not None and BiolibDockerClient.is_docker_running():
             self._start_network_and_remote_host_proxies(job)
 
