@@ -273,6 +273,16 @@ http {{
             proxy_ssl_server_name    on;
         }}
 
+        location ~ "^/api/auth/oauth-token-exchange/$" {{
+            # Note: Using $1 here as URI part from regex must be used for proxy_pass
+            proxy_pass               https://$upstream_hostname/api/auth/oauth-token-exchange/$1;
+            proxy_set_header         authorization "";
+            proxy_set_header         compute-node-auth-token "{compute_node_auth_token}";
+            proxy_set_header         job-uuid "{self._job_uuid}";
+            proxy_set_header         cookie "";
+            proxy_ssl_server_name    on;
+        }}
+
         location /api/lfs/ {{
             proxy_pass               https://$upstream_hostname$request_uri;
             proxy_set_header         authorization "";
