@@ -1,6 +1,6 @@
-from enum import Enum
 import random
 import string
+from enum import Enum
 
 from biolib.biolib_logging import logger
 
@@ -10,17 +10,17 @@ def get_package_type(package):
     if package_type == 1:
         return 'ModuleInput'
     elif package_type == 2:
-        return 'ModuleOutput'
-    elif package_type == 3:  # Not used in the compute node
-        return 'ModuleSource'
+        return 'ModuleOutput'  # Note: This package is deprecated
+    elif package_type == 3:
+        return 'ModuleSource'  # Note: This package is deprecated
     elif package_type == 4:
-        return 'AttestationDocument'
+        return 'AttestationDocument'  # Note: This package is deprecated
     elif package_type == 5:
         return 'SavedJob'
     elif package_type == 6:
-        return 'RsaEncryptedAesPackage'
+        return 'RsaEncryptedAesPackage'  # Note: This package is deprecated
     elif package_type == 7:
-        return 'AesEncryptedPackage'
+        return 'AesEncryptedPackage'  # Note: This package is deprecated
     elif package_type == 8:
         return 'SystemStatusUpdate'
     elif package_type == 9:
@@ -29,7 +29,7 @@ def get_package_type(package):
         return 'StdoutAndStderr'
 
     else:
-        raise Exception(f"Unexpected package type {package_type}")
+        raise Exception(f'Unexpected package type {package_type}')
 
 
 class SystemExceptionCodes(Enum):
@@ -67,6 +67,9 @@ class SystemExceptionCodes(Enum):
     COMMAND_OVERRIDE_NOT_ALLOWED = 31
     FAILED_TO_ALLOCATE_JOB_TO_COMPUTE_NODE = 32
     NO_MODULES_FOUND_ON_JOB = 33
+    FAILED_TO_INITIALIZE_DOCKER_EXECUTOR = 34
+    COMPUTE_NODE_SHUTDOWN = 35
+    COMPUTE_NODE_SHUTDOWN_DUE_TO_HEALTH_CHECK_FAILURE = 36
 
 
 SystemExceptionCodeMap = {
@@ -103,7 +106,10 @@ SystemExceptionCodeMap = {
     30: 'Job was cancelled by the user',
     31: 'The application does not allow the arguments to override the command',
     32: 'Failed to allocate job to compute node',
-    33: 'No modules found on job'
+    33: 'No modules found on job',
+    34: 'Failed to initialize docker executor',
+    35: 'Compute node shutdown',
+    36: 'Compute node shutdown due to health check failure',
 }
 
 
